==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1ServerAddressByClientCIDRFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1ServerAddressByClientCIDRFluentImpl<A extends V1ServerAddressByClientCIDRFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1ServerAddressByClientCIDRFluent<A>{

    private String clientCIDR;
    private String serverAddress;

    public V1ServerAddressByClientCIDRFluentImpl(){
    }
    public V1ServerAddressByClientCIDRFluentImpl(V1ServerAddressByClientCIDR instance){
            this.withClientCIDR(instance.getClientCIDR());

            this.withServerAddress(instance.getServerAddress());

    }

    public String getClientCIDR(){
            return this.clientCIDR;
    }

    public A withClientCIDR(String clientCIDR){
            this.clientCIDR=clientCIDR; return (A) this;
    }

    public Boolean hasClientCIDR(){
            return this.clientCIDR != null;
    }

    public String getServerAddress(){
            return this.serverAddress;
    }

    public A withServerAddress(String serverAddress){
            this.serverAddress=serverAddress; return (A) this;
    }

    public Boolean hasServerAddress(){
            return this.serverAddress != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ServerAddressByClientCIDRFluentImpl that = (V1ServerAddressByClientCIDRFluentImpl) o;
            if (clientCIDR != null ? !clientCIDR.equals(that.clientCIDR) :that.clientCIDR != null) return false;
            if (serverAddress != null ? !serverAddress.equals(that.serverAddress) :that.serverAddress != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ServerAddressByClientCIDRFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1ServerAddressByClientCIDRFluentImpl<A extends V1ServerAddressByClientCIDRFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1ServerAddressByClientCIDRFluent<A>{

    private String clientCIDR;
    private String serverAddress;

    public V1ServerAddressByClientCIDRFluentImpl(){
    }
    public V1ServerAddressByClientCIDRFluentImpl(V1ServerAddressByClientCIDR instance){
            this.withClientCIDR(instance.getClientCIDR());

            this.withServerAddress(instance.getServerAddress());

    }

    public String getClientCIDR(){
            return this.clientCIDR;
    }

    public A withClientCIDR(String clientCIDR){
            this.clientCIDR=clientCIDR; return (A) this;
    }

    public Boolean hasClientCIDR(){
            return this.clientCIDR != null;
    }

    public A withNewClientCIDR(String arg1){
            return (A)withClientCIDR(new String(arg1));
    }

    public A withNewClientCIDR(StringBuilder arg1){
            return (A)withClientCIDR(new String(arg1));
    }

    public A withNewClientCIDR(StringBuffer arg1){
            return (A)withClientCIDR(new String(arg1));
    }

    public String getServerAddress(){
            return this.serverAddress;
    }

    public A withServerAddress(String serverAddress){
            this.serverAddress=serverAddress; return (A) this;
    }

    public Boolean hasServerAddress(){
            return this.serverAddress != null;
    }

    public A withNewServerAddress(String arg1){
            return (A)withServerAddress(new String(arg1));
    }

    public A withNewServerAddress(StringBuilder arg1){
            return (A)withServerAddress(new String(arg1));
    }

    public A withNewServerAddress(StringBuffer arg1){
            return (A)withServerAddress(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ServerAddressByClientCIDRFluentImpl that = (V1ServerAddressByClientCIDRFluentImpl) o;
            if (clientCIDR != null ? !clientCIDR.equals(that.clientCIDR) :that.clientCIDR != null) return false;
            if (serverAddress != null ? !serverAddress.equals(that.serverAddress) :that.serverAddress != null) return false;
            return true;
    }




}
